@@ -30,7 +30,7 @@ class Node:
         self._prev_node = prev_node
         self._next_node = next_node
         self._attrs = attrs
-        self.text = ''
+        self._text = []
         if attrs:
             for pair in attrs:
                 key = pair[0] if pair[0] != 'class' else 'class_'
@@ -40,6 +40,12 @@ class Node:
         # is closed tag for this Node was found
         self.closed = False
 
+    @property
+    def text(self):
+        if not self._text:
+            return ''
+        return '\n'.join(self._text)
+
     def __contains__(self, item):
         """
         For using "'attr' in node" syntax  with filter
@@ -59,19 +65,18 @@ class Node:
         return self.__dict__[item]
 
     def _set_text(self, text):
-        if text is None or len(text.rstrip()) == 0:
-            return
-        else:
-            self.text = text if not self.text else self.text + '\n' + text
+        if text and text.strip():
+            self._text.append(text)
 
+    @property
     def cleared_text(self) -> str:
         """
         Return text of the element without leading/following spaces, tabs (\t), new line characters(\n).
         :return: text after replacing
         """
-        if not self.text:
+        if not self._text:
             return ''
-        return self.text.replace('\n', '').replace('\t', '').strip()
+        return '\n'.join(e.replace('\n', '').replace('\t', '').replace('\r', '').strip() for e in self._text)
 
     def __repr__(self):
         text = '' if not self.text else f' text={self.text},'
