@@ -127,7 +127,7 @@ class Nodes:
         exactly one arg - node object
         :return Nodes object
         """
-        result = self._flatten(lambda e: e.tag == tag)
-        if filter_:
-            result = result._flatten(filter_)
-        return result
+        result = self.find_all(filter_)
+        nodes = Nodes()
+        nodes.extend([e for e in result if e.tag == tag])
+        return nodes
